Examples
========

Example notebooks / scripts
---------------------------
- ``examples/case_small``: minimal case
- ``examples/case_bess``: battery operation & sizing
- ``examples/case_h2``: hydrogen subsystem

.. note::
    Link these once added to the repository.
